	  SUBROUTINE CHCELL (BCELL,ICELL,ANG)
C READ UNIT AND REDUCED CELL INFO
C
C	BCELL		BIT MAP FOR CELLS, 1=>CELL VALUE WAS DEFINED
C			FIRST THREE BITS ARE FOR UNIT CELL, NEXT THREE FOR
C			REDUCED CELL
C	ICELL		UNIT CELL VALUE(S)*100
C	ANG		RETURNED AS CELL ANGLES
C
C	CALLED BY:	CHEM
C	CALLS:		NONE
C
	IMPLICIT BYTE (B), LOGICAL*1 (L), INTEGER*2 (I-K,M,N)
	DIMENSION ICELL(6),ILOC(3),BITS(3),ANG(3,2)
	DATA ILOC/1,9,17/
	DATA BITS/1,2,4/
	DATA I17/"17/
	IJ = 0
	DO 100 IC=1,2
	    DO 20 J=1,3
C BIT NOT SET => ANGLE IS 90
	      IF ((BCELL.AND.BITS(J)) .EQ. 0) THEN
	        ANG(J,IC) = 90.	      
	      ELSE
C ANGLE AS STORED * 100, SO DIVIDE BY 100 AND SAVE VALUE
	        IJ = IJ + 1
	        ANG(J,IC) = FLOAT(ICELL(IJ))/100.
	      END IF
20	      CONTINUE
C SECOND NIBBLE HAS REDUCED CELL ANGLE INFO.
	  BCELL = BCELL/I17		!GET NEXT NIBBLE
100	  CONTINUE
	RETURN
	END
